@@ -58,6 +58,7 @@ def init(
     verbose: Optional[bool] = None,
     throw_errors: Optional[bool] = None,
     debug: Optional[bool] = None,
+    http_timeout_seconds: Optional[int] = None,
 ):
     """Initialize the Aporia SDK.
 
@@ -66,9 +67,10 @@ def init(
         host: Controller host.
         environment: Environment in which aporia is initialized (e.g production, staging).
         port: Controller port. Defaults to 443.
-        verbose: True to enable verbose error messages. Defaults to False
+        verbose: True to enable verbose error messages. Defaults to False.
         throw_errors: True to cause errors to be raised as exceptions. Defaults to False.
         debug: True to enable debug logs and stack traces in log messages. Defaults to False.
+        http_timeout_seconds: HTTP timeout in seconds. Defaults to 30.
 
     Notes:
         * The token, host and environment parameters are required.
@@ -80,6 +82,7 @@ def init(
             * verbose -> APORIA_VERBOSE
             * throw_errors -> APORIA_THROW_ERRORS
             * debug -> APORIA_DEBUG
+            * http_timeout_seconds -> APORIA_HTTP_TIMEOUT_SECONDS
         * Values passed as parameters to aporia.init() override the values from
           the corresponding environment variables.
     """
@@ -96,12 +99,13 @@ def init(
             verbose=verbose,
             throw_errors=throw_errors,
             debug=debug,
+            http_timeout_seconds=http_timeout_seconds,
         )
 
         set_log_level(config.debug)
 
         event_loop = EventLoop()
-        http_client = HttpClient(token=config.token, host=config.host, port=config.port)
+        http_client = HttpClient(token=config.token, host=config.host, port=config.port, default_timeout=config.http_timeout_seconds)
 
         init_context(http_client=http_client, event_loop=event_loop, config=config)
 
