@@ -38,7 +38,7 @@ Please try one of the following solutions:
 class HttpClient:
     """Asynchronous http client."""
 
-    def __init__(self, token: str, host: str, port: int):
+    def __init__(self, token: str, host: str, port: int, default_timeout: int):
         """Initialize a HttpClient instance.
 
         Args:
@@ -55,6 +55,7 @@ class HttpClient:
 
         self.headers = {"Authorization": f"Bearer {token}", "Content-Type": "application/json"}
         self.session = None
+        self.default_timeout = default_timeout
 
     async def open(self):
         """Opens the HTTP session."""
@@ -65,8 +66,9 @@ class HttpClient:
         self,
         query: str,
         variables: dict,
-        timeout: int = DEFAULT_TIMEOUT_SEC,
+        timeout: Optional[int] = None,
         retry_on_failure: bool = True,
+        graphql_url: str = None,
     ) -> dict:
         """Executes a GraphQL query and returns the result.
 
@@ -76,6 +78,7 @@ class HttpClient:
             timeout: Timeout for the entire request, in seconds.
             retry_on_failure: True if the request should be retried on failure
                 due to timeout or connection issues.
+            graphql_url: GraphQL API URL.
 
         Returns:
             GraphQL query result
@@ -85,7 +88,7 @@ class HttpClient:
         data = {"query": query, "variables": variables}
         result = await self.request(
             method="POST",
-            url=GRAPHQL_API_PATH,
+            url=GRAPHQL_API_PATH if graphql_url is None else graphql_url,
             data=data,
             timeout=timeout,
             retry_on_failure=retry_on_failure,
@@ -95,7 +98,7 @@ class HttpClient:
     async def delete(
         self,
         url: str,
-        timeout: int = DEFAULT_TIMEOUT_SEC,
+        timeout: Optional[int] = None,
         retry_on_failure: bool = True,
     ) -> Optional[dict]:
         """Performs a DELETE HTTP request (see HttpClient.request())."""
@@ -109,7 +112,7 @@ class HttpClient:
     async def get(
         self,
         url: str,
-        timeout: int = DEFAULT_TIMEOUT_SEC,
+        timeout: Optional[int] = None,
         retry_on_failure: bool = True,
     ) -> Optional[dict]:
         """Performs a GET HTTP request (see HttpClient.request())."""
@@ -124,7 +127,7 @@ class HttpClient:
         self,
         url: str,
         data: dict,
-        timeout: int = DEFAULT_TIMEOUT_SEC,
+        timeout: Optional[int] = None,
         retry_on_failure: bool = True,
     ) -> Optional[dict]:
         """Performs a POST HTTP request (see HttpClient.request())."""
@@ -141,7 +144,7 @@ class HttpClient:
         method: str,
         url: str,
         data: Optional[dict] = None,
-        timeout: int = DEFAULT_TIMEOUT_SEC,
+        timeout: Optional[int] = None,
         retry_on_failure: bool = True,
     ) -> Optional[dict]:
         """Performs an HTTP request.
@@ -158,6 +161,7 @@ class HttpClient:
             The content of the HTTP response.
         """
         num_attempts = REQUEST_MAX_ATTEMPTS if retry_on_failure else 1
+        timeout = timeout if timeout is not None else self.default_timeout
         async for attempt in AsyncRetrying(
             stop=stop_after_attempt(num_attempts),
             wait=wait_exponential(min=REQUEST_RETRY_INITIAL_SLEEP),
@@ -168,7 +172,7 @@ class HttpClient:
                 return await self._request(method=method, url=url, data=data, timeout=timeout)
 
     async def _request(
-        self, method: str, url: str, data: Optional[dict] = None, timeout: int = DEFAULT_TIMEOUT_SEC
+        self, method: str, url: str, data: Optional[dict] = None, timeout: Optional[int] = None
     ) -> Optional[dict]:
         logger.debug(f"Sending {method} request to {url}.")
 
@@ -180,7 +184,7 @@ class HttpClient:
             method=method,
             url=urljoin(self.base_url, normalized_url),
             data=None if data is None else self._serialize(data),
-            timeout=timeout,
+            timeout=timeout if timeout is not None else self.default_timeout,
             ssl=self.ssl_context,
         ) as response:
             response_content = await response.json()
