@@ -275,7 +275,7 @@ class InferenceModel(BaseModel):
             futures = self._futures
             self._futures = []
 
-            logger.debug("Flusing predictions.")
+            logger.debug("Flushing predictions.")
             # Add a task that flushes the queue, and another that waits for the flush to complete
             futures.append(self._event_loop.create_task(self._queue.flush()))
             futures.append(self._event_loop.create_task(self._queue.join()))
