@@ -1,3 +1,4 @@
+from collections import abc
 from typing import Dict, Optional, Union
 
 import numpy as np
@@ -19,12 +20,20 @@ DTYPE_TO_FIELD_TYPE = {
     "U": FieldType.STRING,
 }
 
+NUMERIC_DTYPES = ["i", "u", "f"]
+STRING_DTYPES = ["O", "S", "U"]
+STRING_UNIQUE_RATIO = 0.25
+MIN_UNIQUE_VALUES_FOR_TEXT = 50
 
-def convert_dtype_to_field_type(dtype: np.dtype) -> Optional[FieldType]:
+
+def infer_type_from_dtype_and_data(
+    dtype: np.dtype, data: Optional[pd.Series]
+) -> Optional[FieldType]:
     """Attempts to convert a numpy/pandas dtype to a FieldType.
 
     Args:
         dtype: Dtype to convert
+        data: Numpy data series
 
     Returns:
         FieldType that matches the dtype, or None if conversion is impossible
@@ -37,6 +46,22 @@ def convert_dtype_to_field_type(dtype: np.dtype) -> Optional[FieldType]:
 
         return category_type
 
+    if data is not None and not data.empty:
+        if dtype.kind in NUMERIC_DTYPES and isinstance(data.values[0], abc.Iterable):
+            return FieldType.VECTOR
+
+        # We need to decided if a string type is str or text
+        # We check if there are more than 50 unique values
+        # which are more than 25% of the total values
+        if dtype.kind in STRING_DTYPES and len(data.shape) > 0:
+            _, unique_counts = np.unique(data.values, return_counts=True)
+            uniques = len(unique_counts)
+            if (
+                uniques > MIN_UNIQUE_VALUES_FOR_TEXT
+                and uniques > data.shape[0] * STRING_UNIQUE_RATIO
+            ):
+                return FieldType.TEXT
+
     return DTYPE_TO_FIELD_TYPE.get(dtype.kind)  # type: ignore
 
 
@@ -95,9 +120,12 @@ def infer_schema_from_dataframe(data: pd.DataFrame) -> Optional[Dict[str, str]]:
         * The field types are inferred using the following logic, based on the column dtypes:
             * dtype="category" with numeric (integer of float) categories -> categorical field
             * dtype="category" with non-numeric categories -> See rules below
+            * Array of numeric values (integer or float) -> vector field
             * dtype="bool" -> boolean field
             * dtypes that represent signed/unsigned integers and floating point numbers -> numeric field
             * dtype is "string", "unicode", "object" -> string field
+            * dtype is "string", "unicode", "object", more than 50 values which more than
+                25% of them are unique -> text field
             * dtype is any datetime type (with or without timezone) -> datetime field
         * If data contains a column with a type that doesn't match any of the rules
           described above, an error will be raised.
@@ -112,7 +140,9 @@ def infer_schema_from_dataframe(data: pd.DataFrame) -> Optional[Dict[str, str]]:
         schema = {}
         for column_name, values in data.items():
             values_without_nulls = values.dropna().infer_objects()
-            column_type = convert_dtype_to_field_type(values_without_nulls.dtype)
+            column_type = infer_type_from_dtype_and_data(
+                values_without_nulls.dtype, values_without_nulls
+            )
             if column_type is None:
                 raise AporiaError(
                     "the dtype {} of column {} is not supported".format(
